# An open-source, low-cost 8-channel transmit/receive 3T head coil for pTx developments, MR safety testing and standardization

## Description

This work investigates an open-source, low-cost, 8-channel transmit/receive head coil to enable rapid and reproducible pTx development, safety assessment and evaluation at 3T. FDTD simulations were validated with phantom measurements on a 3T with an external pTx system. Relative and absolute 2D/3D B1+-maps were acquired to compute the CP+ mode, and two RF shims were tailored to enforce B1+ efficiency and homogeneity. The open-access design files could serve as a basis for new RF coil designs or pTx projects without needing high expertise in RF coil development or as a cost-effective alternative for multi-centre studies.

The full ISMRM Abstract submission can be accessed here: --> [ISMRM 2023 submission](Aigner_et.al_ISMRM31_pTxHeadCoil.pdf "ISMRM 2023 submission") <br />
The RF coil design files can be accessed here: TBD <!--[RF coil design files](/designfiles/xxx.zip "RF coil design files")-->

![Fig1](Figures/Fig1.png)
Figure 1: (A): The computer-aided design (CAD) model of the proposed coil; (B): Finite-difference time-domain (FDTD) model of the eight coil elements and Duke's body model; (C): Assembled RF coil including baluns and the connection to the RX/TX switch box and the used 3T system.

![Fig3](Figures/Fig3.png)
Figure 3: Validation of the simulated B1+ of channel 1 (A) and measured B1+ of channel 1 in a matching phantom (B); elements 2-8 were left open. The quantitative comparison of simulated and measured B1+ shows a scaling factor of 1.45 (the pixel-wise evaluation has been performed in the masked phantom region, see Fig.3A and B), consistent with the measured voltage losses due to cable loss and TX/RX switch. The other channels resulted in a similar trend (not shown).

## RF coil specifications 

- 8-channel transmit/receive
- f=128MHz
- inner dimensions: 22x20cm
- B1+ efficiency: about 35µT/sqrt(kW) in the center (CP+ mode)

## Contacts

Name | Email | Institution | Applications
-----|-----|-----|-----|
Christoph Aigner | christoph.aigner@ptb.de | Physikalisch-Technische Bundesanstalt (PTB), Berlin, Germany | parallel transmission imaging techniques
Frank Seifert | frank.seifert@ptb.de | Physikalisch-Technische Bundesanstalt (PTB), Berlin, Germany | pTx and implant safety
Lukas Winter | lukas.winter@ptb.de | Physikalisch-Technische Bundesanstalt (PTB), Berlin, Germany | implant safety, open source hardware distribution
Mads Sloth Vinding | msv@cfin.au.dk | Center of Functionally Integrative Neuroscience (CFIN), Aarhus University, Denmark | RF pulse design


## Contributors (alphabetical order)
Christoph Aigner, Bernd Ittermann, Reiner Montag, Sebastian Schmitter, Frank Seifert, Mads Sloth Vindin, Lukas Winter

## Publications
If you find this useful in your work, please cite:
Aigner, CS, Vinding, MS, Winter, L, Montag, R, Schmitter, S, Ittermann, B and Seifert, F. An open-source, low-cost 8-channel transmit/receive 3T head coil for pTx developments, MR safety testing and standardization, submitted to ISMRM 2023, Toronto, Canada.

## Acknowledgments
This work has received funding from the German Research Foundation (SCHM 2677/4-1, GRK2260), VILLUM FONDEN and the European Partnership on Metrology, co-financed by the European Union's Horizon Europe Research and Innovation Programme and by the Participating States, under grant number 21NRM05 STASIS.

This work is supported by the Open Source Imaging Initiative (OSI²), https://www.opensourceimaging.org/project/8-channel-transmit-receive-rf-coil-for-3t/

## License and Liability
Please check the [DISCLAIMER](DISCLAIMER.pdf "DISCLAIMER")

